==> ssp-center-api-0.8.76-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/ActivityStatisticsDataRsp.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;


import java.io.Serializable;
import java.util.Date;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * ClassName:SlotSlotStatisticsRsp <br/>
 * Function: 活动数据统计. <br/>
 * Date: 2016年12月21日 上午11:40:06 <br/>
 *
 * @author guyan
 * @version
 * @since JDK 1.6
 * @see
 */

public class ActivityStatisticsDataRsp extends BaseStatisticsDataRsp implements Serializable {
    /** 序列号 */
    private static final long serialVersionUID = -7298487524029228671L;
    /** 广告ID */
    private Long              slotId;
    /** 广告名称 */
    private String            slotName;
    /**广告位类型名称*/
    private String            msName;
    /** 媒体ID */
    private Long              appId;
    /** 媒体名称 */
    private String            appName;
    
    /** 当天日期 */
    private Date              curDate;

    /**
     * 广告位性质名称
     */
    private String tagName;

    /**
     * 广告位性质id
     */
    private Long tagId;

    /**
     * slotId.
     *
     * @return the slotId
     * @since JDK 1.6
     */
    public Long getSlotId() {
        return slotId;
    }

    /**
     * slotId.
     *
     * @param slotId the slotId to set
     * @since JDK 1.6
     */
    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    /**
     * slotName.
     *
     * @return the slotName
     * @since JDK 1.6
     */
    public String getSlotName() {
        return slotName;
    }

    /**
     * slotName.
     *
     * @param slotName the slotName to set
     * @since JDK 1.6
     */
    public void setSlotName(String slotName) {
        this.slotName = slotName;
    }

    /**
     * appId.
     *
     * @return the appId
     * @since JDK 1.6
     */
    public Long getAppId() {
        return appId;
    }

    /**
     * appId.
     *
     * @param appId the appId to set
     * @since JDK 1.6
     */
    public void setAppId(Long appId) {
        this.appId = appId;
    }

    /**
     * appName.
     *
     * @return the appName
     * @since JDK 1.6
     */
    public String getAppName() {
        return appName;
    }

    /**
     * appName.
     *
     * @param appName the appName to set
     * @since JDK 1.6
     */
    public void setAppName(String appName) {
        this.appName = appName;
    }

    /**
     * msName.
     *
     * @return the msName
     * @since JDK 1.6
     */
    public String getMsName() {
        return msName;
    }

    /**
     * msName.
     *
     * @param msName the msName to set
     * @since JDK 1.6
     */
    public void setMsName(String msName) {
        this.msName = msName;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);

    }

	public Date getCurDate() {
		return curDate;
	}

	public void setCurDate(Date curDate) {
		this.curDate = curDate;
	}

    public String getTagName() {
        return tagName;
    }

    public void setTagName(String tagName) {
        this.tagName = tagName;
    }

    public Long getTagId() {
        return tagId;
    }

    public void setTagId(Long tagId) {
        this.tagId = tagId;
    }
}

==> ssp-center-api-1.1.59-20230412.084347-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/ActivityStatisticsDataRsp.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;


import java.io.Serializable;
import java.util.Date;
import java.util.List;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * ClassName:SlotSlotStatisticsRsp <br/>
 * Function: 活动数据统计. <br/>
 * Date: 2016年12月21日 上午11:40:06 <br/>
 *
 * @author guyan
 * @version
 * @since JDK 1.6
 * @see
 */

public class ActivityStatisticsDataRsp extends BaseStatisticsDataRsp implements Serializable {
    /** 序列号 */
    private static final long serialVersionUID = -7298487524029228671L;
    /** 广告ID */
    private Long              slotId;
    /** 广告名称 */
    private String            slotName;
    /**广告位类型名称*/
    private String            msName;
    /** 媒体ID */
    private Long              appId;
    /** 媒体名称 */
    private String            appName;
    
    /** 当天日期 */
    private Date              curDate;

    /**
     * 广告位性质名称
     * todo 确认无用后删除掉
     */
    private String tagName;

    /**
     * 广告位性质id
     * todo 确认无用后删除掉
     */
    private Long tagId;

    /**
     * 广告位性质标签
     */
    private List<TagItem> slotProperties;

    /**
     * slotId.
     *
     * @return the slotId
     * @since JDK 1.6
     */
    public Long getSlotId() {
        return slotId;
    }

    /**
     * slotId.
     *
     * @param slotId the slotId to set
     * @since JDK 1.6
     */
    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    /**
     * slotName.
     *
     * @return the slotName
     * @since JDK 1.6
     */
    public String getSlotName() {
        return slotName;
    }

    /**
     * slotName.
     *
     * @param slotName the slotName to set
     * @since JDK 1.6
     */
    public void setSlotName(String slotName) {
        this.slotName = slotName;
    }

    /**
     * appId.
     *
     * @return the appId
     * @since JDK 1.6
     */
    public Long getAppId() {
        return appId;
    }

    /**
     * appId.
     *
     * @param appId the appId to set
     * @since JDK 1.6
     */
    public void setAppId(Long appId) {
        this.appId = appId;
    }

    /**
     * appName.
     *
     * @return the appName
     * @since JDK 1.6
     */
    public String getAppName() {
        return appName;
    }

    /**
     * appName.
     *
     * @param appName the appName to set
     * @since JDK 1.6
     */
    public void setAppName(String appName) {
        this.appName = appName;
    }

    /**
     * msName.
     *
     * @return the msName
     * @since JDK 1.6
     */
    public String getMsName() {
        return msName;
    }

    /**
     * msName.
     *
     * @param msName the msName to set
     * @since JDK 1.6
     */
    public void setMsName(String msName) {
        this.msName = msName;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);

    }

	public Date getCurDate() {
		return curDate;
	}

	public void setCurDate(Date curDate) {
		this.curDate = curDate;
	}

    public String getTagName() {
        return tagName;
    }

    public void setTagName(String tagName) {
        this.tagName = tagName;
    }

    public Long getTagId() {
        return tagId;
    }

    public void setTagId(Long tagId) {
        this.tagId = tagId;
    }

    public List<TagItem> getSlotProperties() {
        return slotProperties;
    }

    public void setSlotProperties(List<TagItem> slotProperties) {
        this.slotProperties = slotProperties;
    }
}
